<!DOCTYPE TS><TS>
<context>
    <name>CFileIO</name>
    <message>
        <source>Open</source>
        <translation>Открыть</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Сохранить</translation>
    </message>
</context>
<context>
    <name>CFileWriter</name>
    <message>
        <source>error</source>
        <translation>Ошибка
</translation>
    </message>
    <message>
        <source>There was an error writing to the selected file.</source>
        <translation>Ошибка записи в выбранный файл
</translation>
    </message>
</context>
<context>
    <name>CFormDef</name>
    <message>
        <source>Sail corners coordinates</source>
        <translation>Координаты углов паруса</translation>
    </message>
    <message>
        <source>tack</source>
        <translation>галсовый угол</translation>
    </message>
    <message>
        <source>clew</source>
        <translation>Шкотовый угол</translation>
    </message>
    <message>
        <source>head</source>
        <translation>фаловый угол</translation>
    </message>
    <message>
        <source>peak</source>
        <translation>задний нок-бензельный угол</translation>
    </message>
    <message>
        <source>IRC width measurements</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>CFormDefBase</name>
    <message>
        <source>Sail definition</source>
        <translation>Характеристика паруса
</translation>
    </message>
    <message>
        <source>OK</source>
        <translation>ОК
</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Layout</source>
        <translation>Макет</translation>
    </message>
    <message>
        <source>Mitre cut</source>
        <translation>Крой под углом 45 градусов</translation>
    </message>
    <message>
        <source>Cross cut</source>
        <translation>Поперечный крой</translation>
    </message>
    <message>
        <source>Twist foot</source>
        <translation>Разновидность поперечного кроя с нижней панелью, параллельной нижней шкаторине</translation>
    </message>
    <message>
        <source>Horizontal cut</source>
        <translation>Горизонтальный крой</translation>
    </message>
    <message>
        <source>Vertical cut</source>
        <translation>Вертикальный крой</translation>
    </message>
    <message>
        <source>Number of luff gores</source>
        <translation>Количество клиньев передней шкаторины</translation>
    </message>
    <message>
        <source>Number of radial gores</source>
        <translation>Количество радиальных клиньев</translation>
    </message>
    <message>
        <source>Number of sections</source>
        <translation>Количество секций</translation>
    </message>
    <message>
        <source>Radial cut</source>
        <translation>Радиальный крой</translation>
    </message>
    <message>
        <source>Sail shape</source>
        <translation>Форма паруса</translation>
    </message>
    <message>
        <source>%</source>
        <translation>% (процент)</translation>
    </message>
    <message>
        <source>Top depth</source>
        <translation>Глубина передней частипрофиля паруса </translation>
    </message>
    <message>
        <source>Mid depth</source>
        <translation>Глубина средней части профиля паруса </translation>
    </message>
    <message>
        <source>Foot depth</source>
        <translation>Глубина задней части профиля паруса</translation>
    </message>
    <message>
        <source>Twist angle</source>
        <translation>угол твиста</translation>
    </message>
    <message>
        <source>Sheeting angle</source>
        <translation>Угол между ДП лодки и линией, соединяющей галсовый и шкотовый углы паруса</translation>
    </message>
    <message>
        <source>deg</source>
        <translation>градусов</translation>
    </message>
    <message>
        <source>Cloth</source>
        <translation>ткань</translation>
    </message>
    <message>
        <source>mm</source>
        <translation>мм</translation>
    </message>
    <message>
        <source>Cloth width</source>
        <translation>Ширина ткани</translation>
    </message>
    <message>
        <source>Leech hem</source>
        <translation>Подгиб задней шкаторины</translation>
    </message>
    <message>
        <source>Other hems</source>
        <translation>Подгиб других кромок</translation>
    </message>
    <message>
        <source>Seam width</source>
        <translation>Ширина шва</translation>
    </message>
    <message>
        <source>Sail-ID</source>
        <translation type="obsolete">Идентификатор ID</translation>
    </message>
    <message>
        <source>Sail ID</source>
        <translation>Идентификатор ID текстового описания паруса</translation>
    </message>
    <message>
        <source>Sail dimensions</source>
        <translation>Размерения паруса</translation>
    </message>
    <message>
        <source>Luff length</source>
        <translation>Длина передней шкаторины</translation>
    </message>
    <message>
        <source>Foot length</source>
        <translation>Длина нижней шкаторины</translation>
    </message>
    <message>
        <source>Leech length</source>
        <translation>Длина задней шкаторины</translation>
    </message>
    <message>
        <source>Gaff length</source>
        <translation>Длина гафеля</translation>
    </message>
    <message>
        <source>Leech round</source>
        <translation>Выпуклость (вогнутость) задней шкаторины</translation>
    </message>
    <message>
        <source>Luff round</source>
        <translation>Выпуклость (вогнутость) передней шкаторины</translation>
    </message>
    <message>
        <source>Gaff round</source>
        <translation>Выпуклость верхней шкаторины гафеля</translation>
    </message>
    <message>
        <source>Gaff angle from luff</source>
        <translation>Угол между гафелем и передней шкаториной</translation>
    </message>
    <message>
        <source>Diagonal</source>
        <translation>Диагональ</translation>
    </message>
    <message>
        <source>Sail area</source>
        <translation>Площадь паруса</translation>
    </message>
    <message encoding="UTF-8">
        <source>m²</source>
        <translation type="obsolete">кв.м</translation>
    </message>
    <message>
        <source>Compute</source>
        <translation>Рассчитать</translation>
    </message>
    <message>
        <source>Round position</source>
        <translation>Положение макс. выпуклости ( вогнутости)</translation>
    </message>
    <message>
        <source>Foot round</source>
        <translation>Выпуклость нижней шкаторины</translation>
    </message>
    <message>
        <source>Rig geometry</source>
        <translation>Геометрия парусной оснастки</translation>
    </message>
    <message>
        <source>Distance tack to stem</source>
        <translation>Удаление галсового угла от форштевня</translation>
    </message>
    <message>
        <source>Main sail</source>
        <translation>Грот</translation>
    </message>
    <message>
        <source>Jib</source>
        <translation>Стаксель</translation>
    </message>
    <message>
        <source>Dihedral angle</source>
        <translation>Двугранный угол</translation>
    </message>
    <message>
        <source>Wing</source>
        <translation>Крыло</translation>
    </message>
    <message>
        <source>Mast / Luff rake</source>
        <translation>Мачта/наклон мачты</translation>
    </message>
    <message>
        <source>Tack height</source>
        <translation>Высота галсового угла</translation>
    </message>
    <message>
        <source>Fore triangle hoist  I</source>
        <translation>Высота крепления штага на мачте от палубы </translation>
    </message>
    <message>
        <source>Fore triangle base  J</source>
        <translation>Расстояние крепления штага на палубе до мачты</translation>
    </message>
    <message>
        <source>Boat length LOA</source>
        <translation>Габаритная длина корпуса лодки</translation>
    </message>
    <message>
        <source>m2</source>
        <translation>м.кв.</translation>
    </message>
    <message>
        <source>Sail identifier</source>
        <translation>Идентификатор паруса</translation>
    </message>
</context>
<context>
    <name>CFormHelp</name>
    <message>
        <source>Sailcut CAD Handbook</source>
        <translation>Справочник по Sailcut CAD</translation>
    </message>
</context>
<context>
    <name>CFormMain</name>
    <message>
        <source>&amp;New</source>
        <translation>Новый 
</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>Открыть </translation>
    </message>
    <message>
        <source>Open &amp;recent</source>
        <translation>Открыть предыдущий</translation>
    </message>
    <message>
        <source>data</source>
        <translation>Данные</translation>
    </message>
    <message>
        <source>drawing</source>
        <translation>Панели в сборе</translation>
    </message>
    <message>
        <source>develop</source>
        <translation type="obsolete">Отдельных панелей</translation>
    </message>
    <message>
        <source>&amp;Print</source>
        <translation>Печатать </translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>Сохранить </translation>
    </message>
    <message>
        <source>Save &amp;As</source>
        <translation>Сохранить как </translation>
    </message>
    <message>
        <source>to &amp;DXF</source>
        <translation>в DXF формат</translation>
    </message>
    <message>
        <source>to &amp;TXT sail</source>
        <translation>в TXT формат</translation>
    </message>
    <message>
        <source>to &amp;XML sail</source>
        <translation>в XML формат</translation>
    </message>
    <message>
        <source>E&amp;xport 3D sail</source>
        <translation>Экспорт 3D паруса</translation>
    </message>
    <message>
        <source>to &amp;Carlson plotter</source>
        <translation>в Carlson плоттер</translation>
    </message>
    <message>
        <source>Export &amp;development</source>
        <translation>Экспорт панелей</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>Выход </translation>
    </message>
    <message>
        <source>&amp;Dimensions</source>
        <translation>Размеры </translation>
    </message>
    <message>
        <source>&amp;Mould</source>
        <translation>Профили</translation>
    </message>
    <message>
        <source>&amp;Patches</source>
        <translation>Накладки </translation>
    </message>
    <message>
        <source>&amp;Rig</source>
        <translation>Парусное вооружение </translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Язык</translation>
    </message>
    <message>
        <source>Sailcut CAD &amp;Handbook</source>
        <translation>Справочник по Sailcut CAD</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>О программе Qt</translation>
    </message>
    <message>
        <source>About &amp;Sailcut CAD</source>
        <translation>о программе Sailcut CAD</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>Файл </translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>Просмотр</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>Помощь </translation>
    </message>
    <message>
        <source>shaded view</source>
        <translation>Внешний вид</translation>
    </message>
    <message>
        <source>wireframe view</source>
        <translation> В контурах</translation>
    </message>
    <message>
        <source>development</source>
        <translation>Раскрой панелей</translation>
    </message>
    <message>
        <source>loaded &apos;%1&apos;</source>
        <translation>Загружен &apos;%1&apos;</translation>
    </message>
    <message>
        <source>created new sail</source>
        <translation>Создан новый парус</translation>
    </message>
    <message>
        <source>About Sailcut CAD</source>
        <translation>О программе Sailcut CAD</translation>
    </message>
    <message>
        <source>error loading &apos;%1&apos;</source>
        <translation>Ошибка загрузки &apos;%1&apos;</translation>
    </message>
    <message>
        <source>Sail type</source>
        <translation type="obsolete">Тип паруса</translation>
    </message>
    <message>
        <source>Mainsail</source>
        <translation type="obsolete">Грот</translation>
    </message>
    <message>
        <source>Jib</source>
        <translation type="obsolete">Стаксель</translation>
    </message>
    <message>
        <source>Wing</source>
        <translation type="obsolete">Крыло</translation>
    </message>
    <message>
        <source>Sail layout</source>
        <translation type="obsolete">Макет паруса</translation>
    </message>
    <message>
        <source>Cross Cut</source>
        <translation type="obsolete">Поперечный крой</translation>
    </message>
    <message>
        <source>Horizontal Cut</source>
        <translation type="obsolete">Горизонтальный крой</translation>
    </message>
    <message>
        <source>Radial Cut</source>
        <translation type="obsolete">Радиальный крой</translation>
    </message>
    <message>
        <source>Twist Foot Cut</source>
        <translation type="obsolete">Поперечный крой , параллельный краю нижней шкаторины</translation>
    </message>
    <message>
        <source>Vertical Cut</source>
        <translation type="obsolete">Вертикальный крой</translation>
    </message>
    <message>
        <source>Mitre Cut</source>
        <translation type="obsolete">Крой под  45 градусов</translation>
    </message>
    <message>
        <source> sections,   </source>
        <translation type="obsolete">Секции</translation>
    </message>
    <message>
        <source> head gores,   </source>
        <translation type="obsolete">Клинья верхней части паруса</translation>
    </message>
    <message>
        <source> luff gores.</source>
        <translation type="obsolete">Клинья передней шкаторины</translation>
    </message>
    <message>
        <source>Rig </source>
        <translation type="obsolete">Парусное вооружение</translation>
    </message>
    <message>
        <source>Boat LOA</source>
        <translation type="obsolete">Габаритный размер лодки</translation>
    </message>
    <message>
        <source>Fore triangle hoist I</source>
        <translation type="obsolete">Высота  крепления штага на мачте от палубы, величина L</translation>
    </message>
    <message>
        <source>Fore triangle base J</source>
        <translation type="obsolete">Проекция штага на палубу, величина J</translation>
    </message>
    <message>
        <source>Tack position X</source>
        <translation type="obsolete">Положение галсового угла X</translation>
    </message>
    <message>
        <source>Tack height Y</source>
        <translation type="obsolete">Высота галсового угла Y</translation>
    </message>
    <message>
        <source>Sail dimensions</source>
        <translation type="obsolete">Размеры паруса</translation>
    </message>
    <message>
        <source>Luff length</source>
        <translation type="obsolete">Длина передней шкаторины</translation>
    </message>
    <message>
        <source>Mast/Luff rake</source>
        <translation type="obsolete">Наклон мачты/штага</translation>
    </message>
    <message>
        <source>Gaff angle wrt luff</source>
        <translation type="obsolete">Угол наклона верхней шкаторины гафеля относительно передней шкаторины</translation>
    </message>
    <message>
        <source>Gaff length</source>
        <translation type="obsolete">Длина верхней шкаторины гафеля</translation>
    </message>
    <message>
        <source>Foot length</source>
        <translation type="obsolete">Длина нижней шкаторины</translation>
    </message>
    <message>
        <source>Leech length</source>
        <translation type="obsolete">Длина задней шкаторины</translation>
    </message>
    <message>
        <source>Shape of edges</source>
        <translation type="obsolete">Форма краев</translation>
    </message>
    <message>
        <source>Luff round</source>
        <translation type="obsolete">Выпуклость передней шкаторины</translation>
    </message>
    <message>
        <source>Gaff round</source>
        <translation type="obsolete">Выпуклость верхней шкаторины гафеля</translation>
    </message>
    <message>
        <source>Leech round</source>
        <translation type="obsolete">Выпуклость задней шкаторины</translation>
    </message>
    <message>
        <source>Foot round</source>
        <translation type="obsolete">Выпуклость нижней шкаторины</translation>
    </message>
    <message>
        <source>Luff round position</source>
        <translation type="obsolete">Положение выпуклости передней шкаторины</translation>
    </message>
    <message>
        <source>Gaff round position</source>
        <translation type="obsolete">Положение выпуклости верхней шкаторины гафеля</translation>
    </message>
    <message>
        <source>Leech round position</source>
        <translation type="obsolete">Положение выпуклости задней шкаторины</translation>
    </message>
    <message>
        <source>Foot round position</source>
        <translation type="obsolete">Положение выпуклости нижней шкаторины</translation>
    </message>
    <message>
        <source>Sail settings</source>
        <translation type="obsolete">Настройки паруса</translation>
    </message>
    <message>
        <source>Twist angle</source>
        <translation type="obsolete">Угол твиста относительно ДП</translation>
    </message>
    <message>
        <source>Sheeting angle</source>
        <translation type="obsolete">Угол между диаметральной плоскостью лодки и линией, соединяющей галсовый и шкотовый углы паруса</translation>
    </message>
    <message>
        <source>Cloth seams and hems</source>
        <translation type="obsolete">Ширина швов ткани и подгиба</translation>
    </message>
    <message>
        <source>Cloth width</source>
        <translation type="obsolete">Ширина ткани</translation>
    </message>
    <message>
        <source>Seams width</source>
        <translation type="obsolete">Ширина шва</translation>
    </message>
    <message>
        <source>Leech hem width</source>
        <translation type="obsolete">Ширина подгиба задней шкаторины</translation>
    </message>
    <message>
        <source>Other hem width</source>
        <translation type="obsolete">Ширина других подгибов</translation>
    </message>
    <message>
        <source>Sail mould</source>
        <translation type="obsolete">Профиль паруса</translation>
    </message>
    <message>
        <source>Luff factor</source>
        <translation type="obsolete">Фактор передней шкаторины</translation>
    </message>
    <message>
        <source>Depth</source>
        <translation type="obsolete">Глубина</translation>
    </message>
    <message>
        <source>Leech factor</source>
        <translation type="obsolete">Фактор задней шкаторины</translation>
    </message>
    <message>
        <source>Top profile</source>
        <translation type="obsolete">профиль верхней части</translation>
    </message>
    <message>
        <source>Mid profile at h = </source>
        <translation type="obsolete">Профиль средней части на h=</translation>
    </message>
    <message>
        <source>Bottom profile</source>
        <translation type="obsolete">Профиль нижней части</translation>
    </message>
    <message>
        <source>error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <source>There was a data printing error</source>
        <translation>Ошибка печати данных</translation>
    </message>
    <message>
        <source>There was a development printing error</source>
        <translation>ошибка  печати панелей</translation>
    </message>
    <message>
        <source>There was a drawing printing error</source>
        <translation>Ошибка печати панелей в сборе</translation>
    </message>
    <message>
        <source>wrote &apos;%1&apos;</source>
        <translation>Записан &apos;%1&apos;</translation>
    </message>
    <message>
        <source>There was an error writing to the selected file</source>
        <translation>Ошибка записи в выбранный файл</translation>
    </message>
    <message>
        <source>deg</source>
        <translation type="obsolete">градус</translation>
    </message>
    <message>
        <source>to &amp;Hand-plotting format</source>
        <translation>в форматдля ручного черчения</translation>
    </message>
</context>
<context>
    <name>CFormMould</name>
    <message>
        <source>Top profile</source>
        <translation>Профиль верхней части</translation>
    </message>
    <message>
        <source>Middle profile</source>
        <translation>Профиль средней части</translation>
    </message>
    <message>
        <source>Bottom profile</source>
        <translation>Профиль нижней части</translation>
    </message>
    <message>
        <source>Sail mould</source>
        <translation>Профиль паруса</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>Помощь </translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>ОК</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>Отмена</translation>
    </message>
    <message>
        <source>Vertical repartition</source>
        <translation>Вертикальный профиль</translation>
    </message>
</context>
<context>
    <name>CFormRig</name>
    <message>
        <source>Rig</source>
        <translation>Парусное вооружение</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>Новый </translation>
    </message>
    <message>
        <source>sail &amp;definition</source>
        <translation>Характеристика паруса</translation>
    </message>
    <message>
        <source>3D &amp;sail</source>
        <translation>Парус в 3D</translation>
    </message>
    <message>
        <source>&amp;Add sail</source>
        <translation>Добавить парус</translation>
    </message>
    <message>
        <source>&amp;Open</source>
        <translation>Открыть </translation>
    </message>
    <message>
        <source>Open &amp;recent</source>
        <translation>Открыть предыдущий </translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>Сохранить </translation>
    </message>
    <message>
        <source>Save &amp;As</source>
        <translation>Сохранить как </translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>Закрыть</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>Файл </translation>
    </message>
    <message>
        <source>error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <source>There was an error writing to the selected file</source>
        <translation>Ошибка записи в выбранный файл</translation>
    </message>
</context>
<context>
    <name>CRigSailWidget</name>
    <message>
        <source>Sail information</source>
        <translation>Информация о парусе</translation>
    </message>
    <message>
        <source>file</source>
        <translation>файл</translation>
    </message>
    <message>
        <source>name</source>
        <translation>Имя</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Перезагрузить</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Удалить</translation>
    </message>
    <message>
        <source>Update</source>
        <translation>Обновить</translation>
    </message>
    <message>
        <source>error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <source>There was an error reading from the selected file.</source>
        <translation>Была обнаружена ошибка чтения  выбранного файла</translation>
    </message>
</context>
<context>
    <name>CSailDispGL</name>
    <message>
        <source>This system has no OpenGL support.</source>
        <translation type="obsolete">Эта система не имеет поддержки OpenGL</translation>
    </message>
</context>
<context>
    <name>CSailPrinter</name>
    <message>
        <source>Sailcut CAD data sheet</source>
        <translation>Таблица данных Sailcut CAD</translation>
    </message>
    <message>
        <source>Mainsail</source>
        <translation>Грот</translation>
    </message>
    <message>
        <source>Jib</source>
        <translation>Стаксель</translation>
    </message>
    <message>
        <source>Wing</source>
        <translation>Крыло</translation>
    </message>
    <message>
        <source>deg</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sail type</source>
        <translation>Тип паруса</translation>
    </message>
    <message>
        <source>Cross Cut</source>
        <translation>Поперечный крой</translation>
    </message>
    <message>
        <source>Horizontal Cut</source>
        <translation>Горизонтальный крой</translation>
    </message>
    <message>
        <source>Radial Cut</source>
        <translation>Радиальный крой</translation>
    </message>
    <message>
        <source>sections</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>head gores</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>luff gores</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Twist Foot Cut</source>
        <translation>Поперечный крой , параллельный краю нижней шкаторины</translation>
    </message>
    <message>
        <source>Vertical Cut</source>
        <translation>Вертикальный крой</translation>
    </message>
    <message>
        <source>Mitre Cut</source>
        <translation>Крой под  45 градусов</translation>
    </message>
    <message>
        <source>Sail layout</source>
        <translation>Макет паруса</translation>
    </message>
    <message>
        <source>Rig</source>
        <translation>Парусное вооружение</translation>
    </message>
    <message>
        <source>Boat LOA</source>
        <translation>Габаритный размер лодки</translation>
    </message>
    <message>
        <source>Mast/Luff rake</source>
        <translation>Наклон мачты/штага</translation>
    </message>
    <message>
        <source>Tack position X</source>
        <translation>Положение галсового угла X</translation>
    </message>
    <message>
        <source>Tack height Y</source>
        <translation>Высота галсового угла Y</translation>
    </message>
    <message>
        <source>Fore triangle hoist I</source>
        <translation>Высота  крепления штага на мачте от палубы, величина L</translation>
    </message>
    <message>
        <source>Fore triangle base J</source>
        <translation>Проекция штага на палубу, величина J</translation>
    </message>
    <message>
        <source>Sail dimensions</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Luff length</source>
        <translation>Длина передней шкаторины</translation>
    </message>
    <message>
        <source>Foot length</source>
        <translation>Длина нижней шкаторины</translation>
    </message>
    <message>
        <source>Leech length</source>
        <translation>Длина задней шкаторины</translation>
    </message>
    <message>
        <source>Gaff length</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Gaff angle wrt luff</source>
        <translation>Угол наклона верхней шкаторины гафеля относительно передней шкаторины</translation>
    </message>
    <message>
        <source>Shape of edges</source>
        <translation>Форма краев</translation>
    </message>
    <message>
        <source>Luff round</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Luff round position</source>
        <translation>Положение выпуклости передней шкаторины</translation>
    </message>
    <message>
        <source>Foot round</source>
        <translation>Выпуклость нижней шкаторины</translation>
    </message>
    <message>
        <source>Foot round position</source>
        <translation>Положение выпуклости нижней шкаторины</translation>
    </message>
    <message>
        <source>Leech round</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Leech round position</source>
        <translation>Положение выпуклости задней шкаторины</translation>
    </message>
    <message>
        <source>Gaff round</source>
        <translation>Выпуклость верхней шкаторины гафеля</translation>
    </message>
    <message>
        <source>Gaff round position</source>
        <translation>Положение выпуклости верхней шкаторины гафеля</translation>
    </message>
    <message>
        <source>Sail settings</source>
        <translation>Настройки паруса</translation>
    </message>
    <message>
        <source>Twist angle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Sheeting angle</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Cloth seams and hems</source>
        <translation>Ширина швов ткани и подгиба</translation>
    </message>
    <message>
        <source>Cloth width</source>
        <translation>Ширина ткани</translation>
    </message>
    <message>
        <source>Seams width</source>
        <translation>Ширина шва</translation>
    </message>
    <message>
        <source>Leech hem width</source>
        <translation>Ширина подгиба задней шкаторины</translation>
    </message>
    <message>
        <source>Other hem width</source>
        <translation>Ширина других подгибов</translation>
    </message>
    <message>
        <source>Sail mould</source>
        <translation>Профиль паруса</translation>
    </message>
    <message>
        <source>Luff factor</source>
        <translation>Фактор передней шкаторины</translation>
    </message>
    <message>
        <source>Depth</source>
        <translation>Глубина</translation>
    </message>
    <message>
        <source>Leech factor</source>
        <translation>Фактор задней шкаторины</translation>
    </message>
    <message>
        <source>Top profile</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Mid profile at h = </source>
        <translation>Профиль средней части на h=</translation>
    </message>
    <message>
        <source>Bottom profile</source>
        <translation>Профиль нижней части</translation>
    </message>
</context>
<context>
    <name>CSailViewerPanel</name>
    <message>
        <source>Display parameters</source>
        <translation>Параметры внешнего вида</translation>
    </message>
    <message>
        <source>elevation</source>
        <translation>Профиль</translation>
    </message>
    <message>
        <source>azimuth</source>
        <translation>Азимут</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Управление</translation>
    </message>
    <message>
        <source>Reset view</source>
        <translation>К исходному виду</translation>
    </message>
    <message>
        <source>Labeling</source>
        <translation>Установка меток</translation>
    </message>
    <message>
        <source>Zoom in</source>
        <translation>Увеличить</translation>
    </message>
    <message>
        <source>Zoom out</source>
        <translation>Уменьшить</translation>
    </message>
    <message>
        <source>deg</source>
        <translation>Градусов</translation>
    </message>
</context>
<context>
    <name>CWidgetProfile</name>
    <message>
        <source>Luff shape</source>
        <translation>Форма передней шкаторины</translation>
    </message>
    <message>
        <source>Depth</source>
        <translation>Глубина</translation>
    </message>
    <message>
        <source>%</source>
        <translation>%</translation>
    </message>
    <message>
        <source>Leech shape</source>
        <translation>Форма задней шкаторины</translation>
    </message>
    <message>
        <source>degrees</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>cord</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>XmlReaderTempl</name>
    <message>
        <source>error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <source>There was an error reading from the selected file.</source>
        <translation>Обнаружена ошибка чтения  выбранного файла</translation>
    </message>
</context>
</TS>
